@@ -35,10 +35,12 @@ pub use crate::core::rand;
 pub use glutin::*;
 pub use lazy_static;
 pub use tbc;
+pub use walkdir;
 #[cfg(target_arch = "wasm32")]
 pub use winit::*;
 
 pub use rapier3d as physics;
 pub use rg3d_core as core;
+pub use rg3d_resource as asset;
 pub use rg3d_sound as sound;
 pub use rg3d_ui as gui;
