@@ -605,7 +605,7 @@ impl DeferredLightRenderer {
             let raw_radius = match light {
                 Light::Spot(spot_light) => spot_light.distance(),
                 Light::Point(point_light) => point_light.radius(),
-                Light::Directional(_) => std::f32::MAX,
+                Light::Directional(_) => f32::MAX,
             };
 
             let light_position = light.global_position();
@@ -616,7 +616,7 @@ impl DeferredLightRenderer {
             let light_radius_vec = Vector3::new(light_r_inflate, light_r_inflate, light_r_inflate);
             let emit_direction = light
                 .up_vector()
-                .try_normalize(std::f32::EPSILON)
+                .try_normalize(f32::EPSILON)
                 .unwrap_or_else(Vector3::z);
 
             if !frustum.is_intersects_sphere(light_position, light_radius) {
@@ -659,7 +659,7 @@ impl DeferredLightRenderer {
 
                         let light_up_vec = light
                             .look_vector()
-                            .try_normalize(std::f32::EPSILON)
+                            .try_normalize(f32::EPSILON)
                             .unwrap_or_else(Vector3::y);
 
                         let light_view_matrix = Matrix4::look_at_rh(
@@ -831,19 +831,19 @@ impl DeferredLightRenderer {
                                 .set_bool(&shader.soft_shadows, settings.spot_soft_shadows)
                                 .set_vector3(&shader.light_position, &light_position)
                                 .set_vector3(&shader.light_direction, &emit_direction)
-                                .set_float(&shader.light_radius, light_radius)
+                                .set_f32(&shader.light_radius, light_radius)
                                 .set_matrix4(&shader.inv_view_proj_matrix, &inv_view_projection)
                                 .set_color(&shader.light_color, &light.color())
-                                .set_float(
+                                .set_f32(
                                     &shader.half_hotspot_cone_angle_cos,
                                     (spot_light.hotspot_cone_angle() * 0.5).cos(),
                                 )
-                                .set_float(
+                                .set_f32(
                                     &shader.half_cone_angle_cos,
                                     (spot_light.full_cone_angle() * 0.5).cos(),
                                 )
                                 .set_matrix4(&shader.wvp_matrix, &frame_matrix)
-                                .set_float(
+                                .set_f32(
                                     &shader.shadow_map_inv_size,
                                     1.0 / (self.spot_shadow_map_renderer.cascade_size(cascade_index)
                                         as f32),
@@ -858,7 +858,7 @@ impl DeferredLightRenderer {
                                 )
                                 .set_texture(&shader.cookie_texture, &cookie_texture)
                                 .set_bool(&shader.cookie_enabled, cookie_enabled)
-                                .set_float(&shader.shadow_bias, spot_light.shadow_bias());
+                                .set_f32(&shader.shadow_bias, spot_light.shadow_bias());
                         },
                     )
                 }
@@ -878,12 +878,12 @@ impl DeferredLightRenderer {
                                 .set_bool(&shader.shadows_enabled, shadows_enabled)
                                 .set_bool(&shader.soft_shadows, settings.point_soft_shadows)
                                 .set_vector3(&shader.light_position, &light_position)
-                                .set_float(&shader.light_radius, light_radius)
+                                .set_f32(&shader.light_radius, light_radius)
                                 .set_matrix4(&shader.inv_view_proj_matrix, &inv_view_projection)
                                 .set_color(&shader.light_color, &light.color())
                                 .set_matrix4(&shader.wvp_matrix, &frame_matrix)
                                 .set_vector3(&shader.camera_position, &camera_global_position)
-                                .set_float(&shader.shadow_bias, point_light.shadow_bias())
+                                .set_f32(&shader.shadow_bias, point_light.shadow_bias())
                                 .set_texture(&shader.depth_sampler, &gbuffer_depth_map)
                                 .set_texture(&shader.color_sampler, &gbuffer_diffuse_map)
                                 .set_texture(&shader.normal_sampler, &gbuffer_normal_map)
