@@ -828,7 +828,7 @@ impl Renderer {
             frame_buffer,
             frame_width: ui.screen_size().x,
             frame_height: ui.screen_size().y,
-            drawing_context: &ui.draw(),
+            drawing_context: ui.draw(),
             white_dummy: self.white_dummy.clone(),
             texture_cache: &mut self.texture_cache,
         })?;
@@ -960,7 +960,7 @@ impl Renderer {
                     rt.key(),
                     CacheEntry {
                         value: gbuffer.frame_texture(),
-                        time_to_live: std::f32::INFINITY,
+                        time_to_live: f32::INFINITY,
                         value_hash: 0, // TODO
                     },
                 );
@@ -987,6 +987,9 @@ impl Renderer {
                     texture_cache: &mut self.texture_cache,
                     environment_dummy: self.environment_dummy.clone(),
                     use_parallax_mapping: self.quality_settings.use_parallax_mapping,
+                    normal_dummy: self.normal_dummy.clone(),
+                    white_dummy: self.white_dummy.clone(),
+                    graph,
                 });
 
                 let (pass_stats, light_stats) =
