@@ -21,12 +21,12 @@
 //! access to pixels of render target.
 
 use crate::{
+    asset::{define_new_resource, Resource, ResourceData, ResourceState},
     core::{
         futures::io::Error,
         io::{self, FileLoadError},
         visitor::{PodVecView, Visit, VisitError, VisitResult, Visitor},
     },
-    resource::{Resource, ResourceData, ResourceState},
 };
 use ddsfile::{Caps2, D3DFormat};
 use image::{ColorType, DynamicImage, GenericImageView, ImageError, ImageFormat};
@@ -164,6 +164,10 @@ impl ResourceData for TextureData {
     fn path(&self) -> Cow<Path> {
         Cow::Borrowed(&self.path)
     }
+
+    fn set_path(&mut self, path: PathBuf) {
+        self.path = path;
+    }
 }
 
 impl Visit for TextureData {
@@ -223,8 +227,10 @@ impl Default for TextureData {
     }
 }
 
-/// See module docs.
-pub type Texture = Resource<TextureData, TextureError>;
+define_new_resource!(
+    #[doc = "See module docs."],
+    Texture<TextureData, TextureError>
+);
 
 /// Texture state alias.
 pub type TextureState = ResourceState<TextureData, TextureError>;
@@ -234,7 +240,7 @@ impl Texture {
     /// to correct settings, after render target was created, it must not be modified, otherwise
     /// result is undefined.
     pub fn new_render_target(width: u32, height: u32) -> Self {
-        Self::new(TextureState::Ok(TextureData {
+        Self(Resource::new(TextureState::Ok(TextureData {
             path: Default::default(),
             // Render target will automatically set width and height before rendering.
             kind: TextureKind::Rectangle { width, height },
@@ -248,7 +254,7 @@ impl Texture {
             anisotropy: 1.0,
             serialize_content: false,
             data_hash: 0,
-        }))
+        })))
     }
 
     /// Tries to load a texture from given data. Use this method if you want to
@@ -272,10 +278,9 @@ impl Texture {
         data: &[u8],
         compression: CompressionOptions,
     ) -> Result<Self, TextureError> {
-        Ok(Self::new(TextureState::Ok(TextureData::load_from_memory(
-            data,
-            compression,
-        )?)))
+        Ok(Self(Resource::new(TextureState::Ok(
+            TextureData::load_from_memory(data, compression)?,
+        ))))
     }
 
     /// Tries to create new texture from given parameters, it may fail only if size of data passed
@@ -286,12 +291,9 @@ impl Texture {
         bytes: Vec<u8>,
         serialize_content: bool,
     ) -> Option<Self> {
-        Some(Self::new(TextureState::Ok(TextureData::from_bytes(
-            kind,
-            pixel_kind,
-            bytes,
-            serialize_content,
-        )?)))
+        Some(Self(Resource::new(TextureState::Ok(
+            TextureData::from_bytes(kind, pixel_kind, bytes, serialize_content)?,
+        ))))
     }
 }
 
