@@ -23,6 +23,7 @@
 //! is used in skinning (animating 3d model by set of bones).
 
 use crate::{
+    asset::ResourceState,
     core::{
         algebra::{Matrix4, Rotation3, UnitQuaternion, Vector2, Vector3},
         math::{frustum::Frustum, Matrix4Ext},
@@ -33,7 +34,7 @@ use crate::{
         visitor::{Visit, VisitResult, Visitor},
         VecExtensions,
     },
-    resource::{model::NodeMapping, ResourceState},
+    resource::model::NodeMapping,
     scene::{node::Node, transform::TransformBuilder, VisibilityCache},
     utils::log::{Log, MessageKind},
 };
@@ -722,7 +723,7 @@ impl Graph {
                                 MessageKind::Error,
                                 format!(
                                     "Unable to find bone with name {} \
-                                                 starting from node {} in the graph!",
+                                                 starting from node {} in the graph! Bone handle will be removed!",
                                     graph[*bone_handle].name(),
                                     graph[root_handle].name()
                                 ),
@@ -731,6 +732,9 @@ impl Graph {
 
                         *bone_handle = copy;
                     }
+
+                    // Remove invalid handles to prevent panicking.
+                    surface.bones.retain(|h| h.is_some())
                 }
             }
         }
@@ -1053,7 +1057,7 @@ impl Graph {
     /// Returns global scale matrix of a node.
     pub fn global_scale_matrix(&self, node: Handle<Node>) -> Matrix4<f32> {
         let node = &self[node];
-        let local_scale_matrix = Matrix4::new_nonuniform_scaling(&node.local_transform().scale());
+        let local_scale_matrix = Matrix4::new_nonuniform_scaling(node.local_transform().scale());
         if node.parent().is_some() {
             self.global_scale_matrix(node.parent()) * local_scale_matrix
         } else {
