@@ -3,6 +3,7 @@
 //! Utilities module provides set of commonly used algorithms.
 
 pub mod astar;
+pub mod behavior;
 pub mod lightmap;
 pub mod log;
 pub mod navmesh;
@@ -472,7 +473,7 @@ pub fn into_any_arc<T: Any + Send + Sync>(
 
 /// Converts engine's optional texture "pointer" to rg3d-ui's.
 pub fn into_gui_texture(this: Texture) -> draw::SharedTexture {
-    draw::SharedTexture(this.into_inner())
+    draw::SharedTexture(this.0.into_inner())
 }
 
 /// "Transmutes" array of any sized type to a slice of bytes.
